@@ -12,6 +12,7 @@ import time
 import json
 import requests
 from dateutil.relativedelta import relativedelta
+from retrying import retry
 
 
 def datetime_toString(dt: datetime) -> str:
@@ -210,6 +211,7 @@ def monitoring_run_time(f):
         return res
     return wrapper
 
+@retry(stop_max_attempt_number=10)
 def get_taobao_time():
     """获取苏宁时间"""
     url = 'http://quan.suning.com/getSysTime.do'
@@ -217,6 +219,8 @@ def get_taobao_time():
     if ts.status_code == 200:
         json_data = json.loads(ts.text)
         return json_data
+    else:
+        raise ValueError
 if __name__ == '__main__':
     month_begin_day = month_datelist('2020-01')
     print(getdate(1))
